==> gat-0.14.0.tar.gz: gat-0.14.0/docs/themes.md <==
# Highlight Themes

- [`abap`](#abap)
- [`algol`](#algol)
- [`algol_nu`](#algol_nu)
- [`arduino`](#arduino)
- [`autumn`](#autumn)
- [`average`](#average)
- [`base16-snazzy`](#base16-snazzy)
- [`borland`](#borland)
- [`bw`](#bw)
- [`catppuccin-frappe`](#catppuccin-frappe)
- [`catppuccin-latte`](#catppuccin-latte)
- [`catppuccin-macchiato`](#catppuccin-macchiato)
- [`catppuccin-mocha`](#catppuccin-mocha)
- [`colorful`](#colorful)
- [`doom-one`](#doom-one)
- [`doom-one2`](#doom-one2)
- [`dracula`](#dracula)
- [`emacs`](#emacs)
- [`friendly`](#friendly)
- [`fruity`](#fruity)
- [`github`](#github)
- [`github-dark`](#github-dark)
- [`gruvbox`](#gruvbox)
- [`gruvbox-light`](#gruvbox-light)
- [`hr_high_contrast`](#hr_high_contrast)
- [`hrdark`](#hrdark)
- [`igor`](#igor)
- [`lovelace`](#lovelace)
- [`manni`](#manni)
- [`modus-operandi`](#modus-operandi)
- [`modus-vivendi`](#modus-vivendi)
- [`monokai`](#monokai)
- [`monokailight`](#monokailight)
- [`murphy`](#murphy)
- [`native`](#native)
- [`noop`](#noop)
- [`nord`](#nord)
- [`onedark`](#onedark)
- [`onesenterprise`](#onesenterprise)
- [`paraiso-dark`](#paraiso-dark)
- [`paraiso-light`](#paraiso-light)
- [`pastie`](#pastie)
- [`perldoc`](#perldoc)
- [`pygments`](#pygments)
- [`rainbow_dash`](#rainbow_dash)
- [`rose-pine`](#rose-pine)
- [`rose-pine-dawn`](#rose-pine-dawn)
- [`rose-pine-moon`](#rose-pine-moon)
- [`rrt`](#rrt)
- [`solarized-dark`](#solarized-dark)
- [`solarized-dark256`](#solarized-dark256)
- [`solarized-light`](#solarized-light)
- [`swapoff`](#swapoff)
- [`tango`](#tango)
- [`trac`](#trac)
- [`vim`](#vim)
- [`vs`](#vs)
- [`vulcan`](#vulcan)
- [`witchhazel`](#witchhazel)
- [`xcode`](#xcode)
- [`xcode-dark`](#xcode-dark)

## `abap`

![abap](./themes/abap.svg)

## `algol`

![algol](./themes/algol.svg)

## `algol_nu`

![algol_nu](./themes/algol_nu.svg)

## `arduino`

![arduino](./themes/arduino.svg)

## `autumn`

![autumn](./themes/autumn.svg)

## `average`

![average](./themes/average.svg)

## `base16-snazzy`

![base16-snazzy](./themes/base16-snazzy.svg)

## `borland`

![borland](./themes/borland.svg)

## `bw`

![bw](./themes/bw.svg)

## `catppuccin-frappe`

![catppuccin-frappe](./themes/catppuccin-frappe.svg)

## `catppuccin-latte`

![catppuccin-latte](./themes/catppuccin-latte.svg)

## `catppuccin-macchiato`

![catppuccin-macchiato](./themes/catppuccin-macchiato.svg)

## `catppuccin-mocha`

![catppuccin-mocha](./themes/catppuccin-mocha.svg)

## `colorful`

![colorful](./themes/colorful.svg)

## `doom-one`

![doom-one](./themes/doom-one.svg)

## `doom-one2`

![doom-one2](./themes/doom-one2.svg)

## `dracula`

![dracula](./themes/dracula.svg)

## `emacs`

![emacs](./themes/emacs.svg)

## `friendly`

![friendly](./themes/friendly.svg)

## `fruity`

![fruity](./themes/fruity.svg)

## `github`

![github](./themes/github.svg)

## `github-dark`

![github-dark](./themes/github-dark.svg)

## `gruvbox`

![gruvbox](./themes/gruvbox.svg)

## `gruvbox-light`

![gruvbox-light](./themes/gruvbox-light.svg)

## `hr_high_contrast`

![hr_high_contrast](./themes/hr_high_contrast.svg)

## `hrdark`

![hrdark](./themes/hrdark.svg)

## `igor`

![igor](./themes/igor.svg)

## `lovelace`

![lovelace](./themes/lovelace.svg)

## `manni`

![manni](./themes/manni.svg)

## `modus-operandi`

![modus-operandi](./themes/modus-operandi.svg)

## `modus-vivendi`

![modus-vivendi](./themes/modus-vivendi.svg)

## `monokai`

![monokai](./themes/monokai.svg)

## `monokailight`

![monokailight](./themes/monokailight.svg)

## `murphy`

![murphy](./themes/murphy.svg)

## `native`

![native](./themes/native.svg)

## `noop`

![noop](./themes/noop.svg)

## `nord`

![nord](./themes/nord.svg)

## `onedark`

![onedark](./themes/onedark.svg)

## `onesenterprise`

![onesenterprise](./themes/onesenterprise.svg)

## `paraiso-dark`

![paraiso-dark](./themes/paraiso-dark.svg)

## `paraiso-light`

![paraiso-light](./themes/paraiso-light.svg)

## `pastie`

![pastie](./themes/pastie.svg)

## `perldoc`

![perldoc](./themes/perldoc.svg)

## `pygments`

![pygments](./themes/pygments.svg)

## `rainbow_dash`

![rainbow_dash](./themes/rainbow_dash.svg)

## `rose-pine`

![rose-pine](./themes/rose-pine.svg)

## `rose-pine-dawn`

![rose-pine-dawn](./themes/rose-pine-dawn.svg)

## `rose-pine-moon`

![rose-pine-moon](./themes/rose-pine-moon.svg)

## `rrt`

![rrt](./themes/rrt.svg)

## `solarized-dark`

![solarized-dark](./themes/solarized-dark.svg)

## `solarized-dark256`

![solarized-dark256](./themes/solarized-dark256.svg)

## `solarized-light`

![solarized-light](./themes/solarized-light.svg)

## `swapoff`

![swapoff](./themes/swapoff.svg)

## `tango`

![tango](./themes/tango.svg)

## `trac`

![trac](./themes/trac.svg)

## `vim`

![vim](./themes/vim.svg)

## `vs`

![vs](./themes/vs.svg)

## `vulcan`

![vulcan](./themes/vulcan.svg)

## `witchhazel`

![witchhazel](./themes/witchhazel.svg)

## `xcode`

![xcode](./themes/xcode.svg)

## `xcode-dark`

![xcode-dark](./themes/xcode-dark.svg)

==> gat-0.18.0.tar.gz: gat-0.18.0/docs/themes.md <==
# Highlight Themes

- [`abap`](#abap)
- [`algol`](#algol)
- [`algol_nu`](#algol_nu)
- [`arduino`](#arduino)
- [`autumn`](#autumn)
- [`average`](#average)
- [`base16-snazzy`](#base16-snazzy)
- [`borland`](#borland)
- [`bw`](#bw)
- [`catppuccin-frappe`](#catppuccin-frappe)
- [`catppuccin-latte`](#catppuccin-latte)
- [`catppuccin-macchiato`](#catppuccin-macchiato)
- [`catppuccin-mocha`](#catppuccin-mocha)
- [`colorful`](#colorful)
- [`doom-one`](#doom-one)
- [`doom-one2`](#doom-one2)
- [`dracula`](#dracula)
- [`emacs`](#emacs)
- [`friendly`](#friendly)
- [`fruity`](#fruity)
- [`github`](#github)
- [`github-dark`](#github-dark)
- [`gruvbox`](#gruvbox)
- [`gruvbox-light`](#gruvbox-light)
- [`hr_high_contrast`](#hr_high_contrast)
- [`hrdark`](#hrdark)
- [`igor`](#igor)
- [`lovelace`](#lovelace)
- [`manni`](#manni)
- [`modus-operandi`](#modus-operandi)
- [`modus-vivendi`](#modus-vivendi)
- [`monokai`](#monokai)
- [`monokailight`](#monokailight)
- [`murphy`](#murphy)
- [`native`](#native)
- [`noop`](#noop)
- [`nord`](#nord)
- [`onedark`](#onedark)
- [`onesenterprise`](#onesenterprise)
- [`paraiso-dark`](#paraiso-dark)
- [`paraiso-light`](#paraiso-light)
- [`pastie`](#pastie)
- [`perldoc`](#perldoc)
- [`pygments`](#pygments)
- [`rainbow_dash`](#rainbow_dash)
- [`rose-pine`](#rose-pine)
- [`rose-pine-dawn`](#rose-pine-dawn)
- [`rose-pine-moon`](#rose-pine-moon)
- [`rrt`](#rrt)
- [`solarized-dark`](#solarized-dark)
- [`solarized-dark256`](#solarized-dark256)
- [`solarized-light`](#solarized-light)
- [`swapoff`](#swapoff)
- [`tango`](#tango)
- [`tokyonight-day`](#tokyonight-day)
- [`tokyonight-moon`](#tokyonight-moon)
- [`tokyonight-night`](#tokyonight-night)
- [`tokyonight-storm`](#tokyonight-storm)
- [`trac`](#trac)
- [`vim`](#vim)
- [`vs`](#vs)
- [`vulcan`](#vulcan)
- [`witchhazel`](#witchhazel)
- [`xcode`](#xcode)
- [`xcode-dark`](#xcode-dark)

## `abap`

![abap](./themes/abap.svg)

## `algol`

![algol](./themes/algol.svg)

## `algol_nu`

![algol_nu](./themes/algol_nu.svg)

## `arduino`

![arduino](./themes/arduino.svg)

## `autumn`

![autumn](./themes/autumn.svg)

## `average`

![average](./themes/average.svg)

## `base16-snazzy`

![base16-snazzy](./themes/base16-snazzy.svg)

## `borland`

![borland](./themes/borland.svg)

## `bw`

![bw](./themes/bw.svg)

## `catppuccin-frappe`

![catppuccin-frappe](./themes/catppuccin-frappe.svg)

## `catppuccin-latte`

![catppuccin-latte](./themes/catppuccin-latte.svg)

## `catppuccin-macchiato`

![catppuccin-macchiato](./themes/catppuccin-macchiato.svg)

## `catppuccin-mocha`

![catppuccin-mocha](./themes/catppuccin-mocha.svg)

## `colorful`

![colorful](./themes/colorful.svg)

## `doom-one`

![doom-one](./themes/doom-one.svg)

## `doom-one2`

![doom-one2](./themes/doom-one2.svg)

## `dracula`

![dracula](./themes/dracula.svg)

## `emacs`

![emacs](./themes/emacs.svg)

## `friendly`

![friendly](./themes/friendly.svg)

## `fruity`

![fruity](./themes/fruity.svg)

## `github`

![github](./themes/github.svg)

## `github-dark`

![github-dark](./themes/github-dark.svg)

## `gruvbox`

![gruvbox](./themes/gruvbox.svg)

## `gruvbox-light`

![gruvbox-light](./themes/gruvbox-light.svg)

## `hr_high_contrast`

![hr_high_contrast](./themes/hr_high_contrast.svg)

## `hrdark`

![hrdark](./themes/hrdark.svg)

## `igor`

![igor](./themes/igor.svg)

## `lovelace`

![lovelace](./themes/lovelace.svg)

## `manni`

![manni](./themes/manni.svg)

## `modus-operandi`

![modus-operandi](./themes/modus-operandi.svg)

## `modus-vivendi`

![modus-vivendi](./themes/modus-vivendi.svg)

## `monokai`

![monokai](./themes/monokai.svg)

## `monokailight`

![monokailight](./themes/monokailight.svg)

## `murphy`

![murphy](./themes/murphy.svg)

## `native`

![native](./themes/native.svg)

## `noop`

![noop](./themes/noop.svg)

## `nord`

![nord](./themes/nord.svg)

## `onedark`

![onedark](./themes/onedark.svg)

## `onesenterprise`

![onesenterprise](./themes/onesenterprise.svg)

## `paraiso-dark`

![paraiso-dark](./themes/paraiso-dark.svg)

## `paraiso-light`

![paraiso-light](./themes/paraiso-light.svg)

## `pastie`

![pastie](./themes/pastie.svg)

## `perldoc`

![perldoc](./themes/perldoc.svg)

## `pygments`

![pygments](./themes/pygments.svg)

## `rainbow_dash`

![rainbow_dash](./themes/rainbow_dash.svg)

## `rose-pine`

![rose-pine](./themes/rose-pine.svg)

## `rose-pine-dawn`

![rose-pine-dawn](./themes/rose-pine-dawn.svg)

## `rose-pine-moon`

![rose-pine-moon](./themes/rose-pine-moon.svg)

## `rrt`

![rrt](./themes/rrt.svg)

## `solarized-dark`

![solarized-dark](./themes/solarized-dark.svg)

## `solarized-dark256`

![solarized-dark256](./themes/solarized-dark256.svg)

## `solarized-light`

![solarized-light](./themes/solarized-light.svg)

## `swapoff`

![swapoff](./themes/swapoff.svg)

## `tango`

![tango](./themes/tango.svg)

## `tokyonight-day`

![tokyonight-day](./themes/tokyonight-day.svg)

## `tokyonight-moon`

![tokyonight-moon](./themes/tokyonight-moon.svg)

## `tokyonight-night`

![tokyonight-night](./themes/tokyonight-night.svg)

## `tokyonight-storm`

![tokyonight-storm](./themes/tokyonight-storm.svg)

## `trac`

![trac](./themes/trac.svg)

## `vim`

![vim](./themes/vim.svg)

## `vs`

![vs](./themes/vs.svg)

## `vulcan`

![vulcan](./themes/vulcan.svg)

## `witchhazel`

![witchhazel](./themes/witchhazel.svg)

## `xcode`

![xcode](./themes/xcode.svg)

## `xcode-dark`

![xcode-dark](./themes/xcode-dark.svg)
